;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 包管理
(require 'package)
(setq package-enable-at-startup nil)
;; 添加melpa源(更多package)
(add-to-list 'package-archives
			 '("melpa" . "https://melpa.org/packages/"))

(package-initialize)

;; 安装use package
(unless (package-installed-p 'use-package)
  (package-refresh-contents)
  (package-install 'use-package))

;; 编码和语言环境
(prefer-coding-system 'utf-8)

(setenv "LANG" "en_US.UTF-8")
(setenv "LC_ALL" "en_US.UTF-8")
(setenv "LC_CTYPE" "en_US.UTF-8")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 状态栏相关


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; 皮肤,Theme
;; 安全的加载theme
(setq custom-safe-themes t)
;; 白天 座位这屏幕反光. 不能用这个皮肤
;; ;; 使用 doom theme
;; (use-package doom-themes
;;   :ensure t
;;   :config
;;   ;; Global settings (defaults)
;;   (setq doom-themes-enable-bold t    ; if nil, bold is universally disabled
;;     doom-themes-enable-italic t) ; if nil, italics is universally disabled
;;   (load-theme 'doom-one t)
;;   ;; Enable flashing mode-line on errors
;;   (doom-themes-visual-bell-config)
;;   ;; for treemacs users
;;   ;; (setq doom-themes-treemacs-theme "doom-colors") ; use the colorful treemacs theme
;;   ;; (doom-themes-treemacs-config)
;;   ;; Corrects (and improves) org-mode's native fontification.
;;   (doom-themes-org-config))

(use-package monokai-theme
  :ensure t
  :config
  (load-theme 'monokai t))


(use-package company
  :ensure t
  :config
  (global-company-mode)
  ;; (add-to-list 'company-backends #'company-tabnine)
  ;; Optionally enable completion-as-you-type behavior.
  (setq company-idle-delay 0)
  ;; show quik select number
  (setq company-show-numbers t)
  (setq company-minimum-prefix-length 1)
  ;; 大小写问题修复
  (setq company-dabbrev-downcase nil)
  )


(use-package lsp-mode
  :ensure t
  :init
  (setq lsp-keymap-prefix "C-c l")
  :commands (lsp lsp-deferred)
  :hook(
		(go-mode . lsp-deferred)
		(lsp-mode . lsp-enable-which-key-integration)
		)
  :bind (:map lsp-mode-map
			  ("M-." . lsp-find-definition)
			  ("M-n" . lsp-find-references))
  :custom ((lsp-log-io nil)
		   (lsp-eldoc-render-all nil)
		   (lsp-completion-provider t)
		   (lsp-signature-render-documentation nil)
		   (lsp-rust-server 'rust-analyzer)
		   (lsp-rust-analyzer-cargo-watch-enable nil)
		   (lsp-go-hover-kind "NoDocumentation")
		   (lsp-go-use-placeholders t)
		   (lsp-diagnostics-provider :none)
		   (lsp-modeline-diagnostics-enable nil)
		   (lsp-file-watch-threshold 2000))
  )

;; Optional - provides fancier overlays.
(use-package lsp-ui
  :ensure t
  :commands lsp-ui-mode)


;; go语言支持
(use-package go-mode
  :mode "\\.go\\'"
  :init
  (setq gofmt-command "goimports")
  :config
  ;; (add-hook 'go-mode-hook #'nox-go-install-save-hooks)
  ;; (add-hook 'go-mode-hook #'lsp-go-install-save-hooks)
  :hook ((go-mode . lsp))
  :bind
  (:map go-mode-map
		("<f9>" . gofmt))
  )
